import 'dart:async';
import 'dart:convert';
import 'dart:js' as js;
import 'dart:html' as html;

import 'package:flutter/foundation.dart';

class PaymentService {
  final _timerDuration = const Duration(seconds: 1);
  Timer _timer;

  Future<void> startPayment(
      String key,
      int amount,
      String name,
      String email,
      VoidCallback onSuccess,
      VoidCallback onFailed,
      ) async {
    final options = {
      'key': key,
      'amount': amount*100,
      'name': name,
      'prefill': {'name': name, 'email': email}
    };
    if (kIsWeb) {
      final data = await _checkout(options);
      if (data['razorpayStatus'] == 'SUCCESS') {
        print("success");
        onSuccess();
        return;
      }
      onFailed();
    }
  }

  Future<Map<String, String>> _checkout(
      Map<String, dynamic> options
      ) async {
    Completer<Map<String, String>> completer =
    Completer<Map<String, String>>();
    // calls js function defined in Step 3
    js.context.callMethod('checkout', [jsonEncode(options)]);
    _timer = Timer.periodic(_timerDuration, (timer) {
        if(html.window.sessionStorage.containsKey('razorpayStatus')){
          Map<String, String> data = Map.fromEntries(
          html.window.sessionStorage.entries,
          );
          html.window.sessionStorage.clear();
          completer.complete(data);
          _timer.cancel();
          _timer = null;
        }
    });
    return completer.future;
  }

}